@@ -1,20 +1,45 @@
 import logging
 from emitter import Send
+
 """
-Python logging handler for log.io stateless TCP API
+log.io logging handler
+======================
+
+Handler for the python logging framework for log.io stateless TCP API
+
 http://logio.org/
-configuration
-stream: name of log.io
-node: name of log.io
-host: log.io server domain or ip address  (default localhost)
-port: log.io api port (default 28777)
+
+Usage:
+::
+
+    from log_io_handler import LogIOHandler
+
+    Logger.addHandler(LogIOHandler)
+
+    #or dict_config
+    'handlers'
+            'log_io': {
+                'level': 'DEBUG',
+                'class': 'log_io_handler.LogIOHandler',
+                #optional configs
+                'logstream': 'EXAMPLE_STREAM',
+                'node': 'EXAMPLE_NODE',
+                'host': 'EXAMPLE_HOST',
+                'port': 28777,
+            }
+
+        logstream: name of log.io stream default (PythonStream)
+        node: name of log.io node default (PythonNode)
+        host: log.io server domain or ip address  (default localhost)
+        port: log.io api port (default 28777)
 """
 
-VERSION = '1.0'
+VERSION = '1.1'
 AUTHOR = "Raymond McGinlay"
 EMAIL = "raymond@thisislevelup.com"
 URL = "www.thisislevelup.com"
 
+
 class LogIOHandler(logging.Handler):
     """A log handler that transmits log entries to log.io server.
 
